@@ -6,6 +6,7 @@ import sys
 from functools import partial, wraps
 from six import iteritems as items
 
+from . import patch
 from . import mock
 
 sentinel = object()
@@ -61,6 +62,11 @@ class _patching(object):
         self.monkeypatch.setattr(path, value)
         return value
 
+    def object(self, target, attribute, *args, **kwargs):
+        return _wrap_context(
+            patch.object(target, attribute, *args, **kwargs),
+            self.request)
+
     def _value_or_mock(self, value, new, name, path, **kwargs):
         if value is sentinel:
             value = new(name=name or path.rpartition('.')[2])
